==> util-1.0.90-sources.jar: cn/lsmya/helper/ToolsHelper.kt <==
package cn.lsmya.helper

import android.annotation.SuppressLint
import android.content.Context
import android.graphics.Color
import android.graphics.drawable.Drawable
import androidx.annotation.ColorInt
import androidx.core.content.ContextCompat
import cn.lsmya.helper.util.LogHelper
import com.tencent.smtt.sdk.QbSdk

class ToolsHelper {
    companion object {

        @SuppressLint("StaticFieldLeak")
        private lateinit var mContext: Context
        private var mDebug: Boolean = false
        private var titleBackgroundColor: Int = Color.BLACK
        private var titleTextColor: Int = 0
        private var backDrawable: Drawable? = null
        private var emptyResId: Int = R.layout.kit_empty
        private var loadingResId: Int = R.layout.kit_loading
        private var loadingDialogSize: Float = 45f
        private var loadingDialogColor: Int = Color.GRAY
        private var mLightMode: Boolean = false
        private var mDarkModeStatus: Boolean = true
        private var mBottomNavigationViewColor: Int =
            R.color.kit_bottom_nav_color_white

        @JvmStatic
        fun init(context: Context) {
            mContext = context
            QbSdk.setDownloadWithoutWifi(true)
            QbSdk.initX5Environment(mContext, object : QbSdk.PreInitCallback {
                override fun onCoreInitFinished() {

                }

                override fun onViewInitFinished(b: Boolean) {
                    LogHelper.e("TBS", b.toString() + "")
                }
            })
        }

        @JvmStatic
        fun debug(open: Boolean) {
            mDebug = open
        }

        @JvmStatic
        fun debug() = mDebug

        @JvmStatic
        fun getContext(): Context =
            mContext

        /**
         * 初始化标题栏文本字体颜色
         */
        @JvmStatic
        fun initTitleTextColor(@ColorInt color: Int) {
            titleTextColor = color
        }

        /**
         * 获取标题栏文本字体颜色
         */
        @JvmStatic
        fun getTitleTextColor(): Int {
            return if (titleTextColor == 0) {
                ContextCompat.getColor(
                    mContext,
                    R.color.kit_white
                )
            } else {
                titleTextColor
            }
        }

        /**
         * 初始化标题栏返回按钮图标
         */
        @JvmStatic
        fun initTitleBackIcon(drawable: Drawable) {
            backDrawable = drawable
        }

        /**
         * 获取标题栏返回按钮图标
         */
        @JvmStatic
        fun getTitleBackIcon(): Drawable {
            return if (backDrawable == null) {
                ContextCompat.getDrawable(
                    mContext,
                    R.drawable.kit_arrow_back_black_24dp
                )!!
            } else {
                backDrawable!!
            }
        }

        /**
         * 设置状态栏标题栏背景颜色
         */
        @JvmStatic
        fun initTitleBackground(@ColorInt color: Int) {
            titleBackgroundColor = color
        }

        /**
         * 获取状态栏标题栏背景颜色
         */
        @JvmStatic
        fun getTitleBackground(): Int =
            titleBackgroundColor

        /**
         * 设置状态栏字体颜色模式
         */
        @JvmStatic
        fun initStatusBarMode(lightMode: Boolean) {
            mLightMode = lightMode
        }

        /**
         * 设置状态栏字体颜色模式，适应系统的深色模式
         */
        @JvmStatic
        fun initStatusBarMode(lightMode: Boolean, darkModeStatus: Boolean) {
            mLightMode = lightMode
            mDarkModeStatus = darkModeStatus
        }

        /**
         * 获取状态栏字体颜色模式
         */
        @JvmStatic
        fun getStatusBarMode(): Boolean =
            mLightMode

        /**
         * 获取状态栏字体颜色是否适应系统的深色模式
         */
        @JvmStatic
        fun getDarkModeStatus(): Boolean =
            mDarkModeStatus

        /**
         * 设置底部导航栏（BottomNavigationView）按钮、文字颜色
         */
        @JvmStatic
        fun initBottomNavigationViewColor(color: Int) {
            mBottomNavigationViewColor = color
        }

        /**
         * 获取底部导航栏（BottomNavigationView）按钮、文字颜色
         */
        @JvmStatic
        fun getBottomNavigationViewColor(): Int =
            mBottomNavigationViewColor

        /**
         * 设置加载弹窗大小
         */
        @JvmStatic
        fun setLoadingDialogSize(size: Float) {
            loadingDialogSize = size
        }

        /**
         * 获取加载弹窗大小
         */
        @JvmStatic
        fun getLoadingDialogSize(): Float =
            loadingDialogSize

        /**
         * 设置加载弹窗颜色
         */
        @JvmStatic
        fun setLoadingDialogColor(@ColorInt color: Int) {
            loadingDialogColor = color
        }

        /**
         * 获取加载弹窗颜色
         */
        @JvmStatic
        fun getLoadingDialogColor(): Int =
            loadingDialogColor

        /**
         * 设置页面加载布局
         */
        @JvmStatic
        fun setLoadingLayout(resId: Int) {
            loadingResId = resId
        }

        /**
         * 获取页面加载布局
         */
        @JvmStatic
        fun getLoadingLayout(): Int =
            loadingResId

        /**
         * 设置页面空布局
         */
        @JvmStatic
        fun setEmptyLayout(resId: Int) {
            emptyResId = resId
        }

        /**
         * 获取页面空布局
         */
        @JvmStatic
        fun getEmptyLayout(): Int =
            emptyResId
    }
}

==> util-1.0.91-sources.jar: cn/lsmya/helper/ToolsHelper.kt <==
package cn.lsmya.helper

import android.annotation.SuppressLint
import android.content.Context
import android.graphics.Color
import android.graphics.drawable.Drawable
import androidx.annotation.ColorInt
import androidx.core.content.ContextCompat
import cn.lsmya.helper.util.LogHelper
import com.tencent.smtt.sdk.QbSdk

class ToolsHelper {
    companion object {

        @SuppressLint("StaticFieldLeak")
        private lateinit var mContext: Context
        private var mDebug: Boolean = false
        private var titleBackgroundColor: Int = Color.BLACK
        private var titleTextColor: Int = 0
        private var backDrawable: Drawable? = null
        private var emptyResId: Int = R.layout.kit_empty
        private var loadingResId: Int = R.layout.kit_loading
        private var loadingDialogSize: Float = 45f
        private var loadingDialogColor: Int = Color.GRAY
        private var mLightMode: Boolean = false
        private var mDarkModeStatus: Boolean = true
        private var mBottomNavigationViewColor: Int =
            R.color.kit_bottom_nav_color_white
        private var textSize: Float = 1f
        @JvmStatic
        fun init(context: Context) {
            mContext = context
            QbSdk.setDownloadWithoutWifi(true)
            QbSdk.initX5Environment(mContext, object : QbSdk.PreInitCallback {
                override fun onCoreInitFinished() {

                }

                override fun onViewInitFinished(b: Boolean) {
                    LogHelper.e("TBS", b.toString() + "")
                }
            })
        }

        @JvmStatic
        fun debug(open: Boolean) {
            mDebug = open
        }

        @JvmStatic
        fun debug() = mDebug

        @JvmStatic
        fun getContext(): Context =
            mContext

        /**
         * 初始化标题栏文本字体颜色
         */
        @JvmStatic
        fun initTitleTextColor(@ColorInt color: Int) {
            titleTextColor = color
        }

        /**
         * 获取标题栏文本字体颜色
         */
        @JvmStatic
        fun getTitleTextColor(): Int {
            return if (titleTextColor == 0) {
                ContextCompat.getColor(
                    mContext,
                    R.color.kit_white
                )
            } else {
                titleTextColor
            }
        }

        /**
         * 初始化标题栏返回按钮图标
         */
        @JvmStatic
        fun initTitleBackIcon(drawable: Drawable) {
            backDrawable = drawable
        }

        /**
         * 获取标题栏返回按钮图标
         */
        @JvmStatic
        fun getTitleBackIcon(): Drawable {
            return if (backDrawable == null) {
                ContextCompat.getDrawable(
                    mContext,
                    R.drawable.kit_arrow_back_black_24dp
                )!!
            } else {
                backDrawable!!
            }
        }

        /**
         * 设置状态栏标题栏背景颜色
         */
        @JvmStatic
        fun initTitleBackground(@ColorInt color: Int) {
            titleBackgroundColor = color
        }

        /**
         * 获取状态栏标题栏背景颜色
         */
        @JvmStatic
        fun getTitleBackground(): Int =
            titleBackgroundColor

        /**
         * 设置状态栏字体颜色模式
         */
        @JvmStatic
        fun initStatusBarMode(lightMode: Boolean) {
            mLightMode = lightMode
        }

        /**
         * 设置状态栏字体颜色模式，适应系统的深色模式
         */
        @JvmStatic
        fun initStatusBarMode(lightMode: Boolean, darkModeStatus: Boolean) {
            mLightMode = lightMode
            mDarkModeStatus = darkModeStatus
        }

        /**
         * 获取状态栏字体颜色模式
         */
        @JvmStatic
        fun getStatusBarMode(): Boolean =
            mLightMode

        /**
         * 获取状态栏字体颜色是否适应系统的深色模式
         */
        @JvmStatic
        fun getDarkModeStatus(): Boolean =
            mDarkModeStatus

        /**
         * 设置底部导航栏（BottomNavigationView）按钮、文字颜色
         */
        @JvmStatic
        fun initBottomNavigationViewColor(color: Int) {
            mBottomNavigationViewColor = color
        }

        /**
         * 获取底部导航栏（BottomNavigationView）按钮、文字颜色
         */
        @JvmStatic
        fun getBottomNavigationViewColor(): Int =
            mBottomNavigationViewColor

        /**
         * 设置加载弹窗大小
         */
        @JvmStatic
        fun setLoadingDialogSize(size: Float) {
            loadingDialogSize = size
        }

        /**
         * 获取加载弹窗大小
         */
        @JvmStatic
        fun getLoadingDialogSize(): Float =
            loadingDialogSize

        /**
         * 设置加载弹窗颜色
         */
        @JvmStatic
        fun setLoadingDialogColor(@ColorInt color: Int) {
            loadingDialogColor = color
        }

        /**
         * 获取加载弹窗颜色
         */
        @JvmStatic
        fun getLoadingDialogColor(): Int =
            loadingDialogColor

        /**
         * 设置页面加载布局
         */
        @JvmStatic
        fun setLoadingLayout(resId: Int) {
            loadingResId = resId
        }

        /**
         * 获取页面加载布局
         */
        @JvmStatic
        fun getLoadingLayout(): Int =
            loadingResId

        /**
         * 设置页面空布局
         */
        @JvmStatic
        fun setEmptyLayout(resId: Int) {
            emptyResId = resId
        }

        /**
         * 获取页面空布局
         */
        @JvmStatic
        fun getEmptyLayout(): Int =
            emptyResId

        /**
         * 设置字体大小系数
         */
        @JvmStatic
        fun setTextSize(size: Float) {
            textSize = size
        }

        /**
         * 获取字体大小系数
         */
        @JvmStatic
        fun getTextSize(): Float=
            textSize

    }
}
